# -*- coding: utf-8 -*-

"""
####################################################################
#                                                                  #
#                           AWI Basemap                            #
#            PROCESS GREENLAND ICE MAPPING PROJECT DATA            #
#                                                                  #
####################################################################

This script is processing the Greenland Ice Mapping Project (GIMP)
input for the AWI Basemap. The raster is downsampled for easier data
handling and then polygonized to get a vector dataset.

"""


#=============================================================================
#    SCRIPT INFO
#=============================================================================

__author__ = 'Simon Dreutter'
__version__ = '0.3'
__date__ = '2021-11-05'
__email__ = 'simon.dreutter@awi.de'
__status__ = 'Developement'


#=============================================================================
#    IMPORT
#=============================================================================

import os

# import AWI Basemap configuration
from config import *


#=============================================================================
#    PROCESS
#=============================================================================

# layer names
gimp_name = os.path.splitext(os.path.basename(GIMP))[0]

# heading
print()
print('====================================================================')
print(f'{"GREENLAND ICE MAPPING PROJECT / GIMP":^68}')

msg = 'Reprojecting and downsampling GIMP raster...'
cmd = (f'gdalwarp'
       f' -t_srs {EPSG_WORLD}'
       f' -dstnodata 0.0'
       f' -tr {GIMP_RESOLUTION} {GIMP_RESOLUTION}'
       f' -r near'
       f' -of GTiff'
       f' {GIMP_IN} {GIMP_RASTER}')
run(msg,cmd)

msg = 'Polygonizing GIMP raster...'
cmd = (f'gdal_polygonize'
       f' {GIMP_RASTER} {GIMP}'
       f' -b 1'
       f' -f "GPKG"'
       f' {gimp_name} DN')
run(msg,cmd)

# cleanup
cleanup(GIMP_RASTER)
